==> zio-aws-workspaces_2.13-6.20.120.1-sources.jar: zio/aws/workspaces/model/WorkspaceImageIngestionProcess.scala <==
package zio.aws.workspaces.model
import scala.jdk.CollectionConverters._
sealed trait WorkspaceImageIngestionProcess {
  def unwrap: software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess
}
object WorkspaceImageIngestionProcess {
  def wrap(
      value: software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess
  ): zio.aws.workspaces.model.WorkspaceImageIngestionProcess = value match {
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR =>
      val r = BYOL_REGULAR
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS =>
      val r = BYOL_GRAPHICS
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICSPRO =>
      val r = BYOL_GRAPHICSPRO
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS_G4_DN =>
      val r = BYOL_GRAPHICS_G4DN
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_WSP =>
      val r = BYOL_REGULAR_WSP
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_BYOP =>
      val r = BYOL_REGULAR_BYOP
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS_G4_DN_BYOP =>
      val r = BYOL_GRAPHICS_G4DN_BYOP
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.UNKNOWN_TO_SDK_VERSION
  }
  case object BYOL_REGULAR
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR
  }
  case object BYOL_GRAPHICS
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS
  }
  case object BYOL_GRAPHICSPRO
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICSPRO
  }
  case object BYOL_GRAPHICS_G4DN
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS_G4_DN
  }
  case object BYOL_REGULAR_WSP
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_WSP
  }
  case object BYOL_REGULAR_BYOP
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_BYOP
  }
  case object BYOL_GRAPHICS_G4DN_BYOP
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS_G4_DN_BYOP
  }
}

==> zio-aws-workspaces_3-5.17.124.1-sources.jar: zio/aws/workspaces/model/WorkspaceImageIngestionProcess.scala <==
package zio.aws.workspaces.model
import scala.jdk.CollectionConverters.*
sealed trait WorkspaceImageIngestionProcess {
  def unwrap: software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess
}
object WorkspaceImageIngestionProcess {
  def wrap(
      value: software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess
  ): zio.aws.workspaces.model.WorkspaceImageIngestionProcess = value match {
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR =>
      val r = BYOL_REGULAR
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS =>
      val r = BYOL_GRAPHICS
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICSPRO =>
      val r = BYOL_GRAPHICSPRO
      r
    case software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_WSP =>
      val r = BYOL_REGULAR_WSP
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.UNKNOWN_TO_SDK_VERSION
  }
  case object BYOL_REGULAR
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR
  }
  case object BYOL_GRAPHICS
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICS
  }
  case object BYOL_GRAPHICSPRO
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_GRAPHICSPRO
  }
  case object BYOL_REGULAR_WSP
      extends zio.aws.workspaces.model.WorkspaceImageIngestionProcess {
    override def unwrap
        : software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess =
      software.amazon.awssdk.services.workspaces.model.WorkspaceImageIngestionProcess.BYOL_REGULAR_WSP
  }
}
